@@ -1,8 +1,8 @@
-/* Copyright © 2005-2007  Roger Leigh <rleigh@debian.org>
+/* Copyright © 2005-2008  Roger Leigh <rleigh@debian.org>
  *
- * schroot is free software; you can redistribute it and/or modify it
+ * schroot is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * schroot is distributed in the hope that it will be useful, but
@@ -11,9 +11,8 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
- * MA  02111-1307  USA
+ * along with this program.  If not, see
+ * <http://www.gnu.org/licenses/>.
  *
  *********************************************************************/
 
@@ -130,7 +129,7 @@ namespace sbuild
   template <typename K, typename P = basic_keyfile_parser<K> >
   class basic_keyfile : public keyfile_base
   {
-  private:
+  public:
     /// Group name.
     typedef typename K::group_name_type group_name_type;
 
@@ -146,6 +145,7 @@ namespace sbuild
     /// Line number.
     typedef typename K::size_type size_type;
 
+  private:
     /// Parse type.
     typedef P parse_type;
 
@@ -202,6 +202,18 @@ namespace sbuild
     string_list
     get_keys (group_name_type const& group) const;
 
+    /**
+     * Check for unused keys in a group.  If keys other than the
+     * specified keys exist in the specified group, print a warning
+     * about unknown keys having been used.
+     *
+     * @param group the group to use.
+     * @param keys the keys which have been used.
+     */
+    void
+    check_keys (group_name_type const& group,
+		string_list const&     keys) const;
+
     /**
      * Check if a group exists.
      *
