@@ -1,8 +1,8 @@
-/* Copyright © 2005-2007  Roger Leigh <rleigh@debian.org>
+/* Copyright © 2005-2008  Roger Leigh <rleigh@debian.org>
  *
- * schroot is free software; you can redistribute it and/or modify it
+ * schroot is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * schroot is distributed in the hope that it will be useful, but
@@ -11,9 +11,8 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
- * MA  02111-1307  USA
+ * along with this program.  If not, see
+ * <http://www.gnu.org/licenses/>.
  *
  *********************************************************************/
 
@@ -105,7 +104,7 @@ chroot_directory::get_session_flags () const
   if (get_run_setup_scripts() == true)
     return SESSION_CREATE;
   else
-    return static_cast<session_flags>(0);
+    return SESSION_NOFLAGS;
 }
 
 void
@@ -124,11 +123,13 @@ chroot_directory::get_keyfile (keyfile& keyfile) const
 }
 
 void
-chroot_directory::set_keyfile (keyfile const& keyfile)
+chroot_directory::set_keyfile (keyfile const& keyfile,
+			       string_list&   used_keys)
 {
-  chroot::set_keyfile(keyfile);
+  chroot::set_keyfile(keyfile, used_keys);
 
   keyfile::get_object_value(*this, &chroot_directory::set_location,
 			    keyfile, get_name(), "location",
 			    keyfile::PRIORITY_REQUIRED);
+  used_keys.push_back("location");
 }
