@@ -1,8 +1,8 @@
-/* Copyright © 2005-2007  Roger Leigh <rleigh@debian.org>
+/* Copyright © 2005-2008  Roger Leigh <rleigh@debian.org>
  *
- * schroot is free software; you can redistribute it and/or modify it
+ * schroot is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * schroot is distributed in the hope that it will be useful, but
@@ -11,9 +11,8 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
- * MA  02111-1307  USA
+ * along with this program.  If not, see
+ * <http://www.gnu.org/licenses/>.
  *
  *********************************************************************/
 
@@ -26,11 +25,6 @@
 #include <cerrno>
 #include <cstring>
 
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <sys/sysmacros.h>
-#include <unistd.h>
-
 #include <boost/format.hpp>
 
 using boost::format;
@@ -121,16 +115,14 @@ chroot_file::setup_lock (chroot::setup_type type,
   // Check ownership and permissions.
   if (type == SETUP_START && lock == true)
     {
-      struct stat statbuf;
-      if (stat(this->file.c_str(), &statbuf) < 0)
-	throw error(this->file, FILE_STAT, strerror(errno));
+      stat file_status(this->file);
 
       // NOTE: taken from chroot_config::check_security.
-      if (statbuf.st_uid != 0)
+      if (file_status.uid() != 0)
 	throw error(this->file, FILE_OWNER);
-      if (statbuf.st_mode & S_IWOTH)
+      if (file_status.check_mode(stat::PERM_OTHER_WRITE))
 	throw error(this->file, FILE_PERMS);
-      if (!S_ISREG(statbuf.st_mode))
+      if (!file_status.is_regular())
 	throw error(this->file, FILE_NOTREG);
     }
 
@@ -148,7 +140,7 @@ chroot_file::setup_lock (chroot::setup_type type,
 sbuild::chroot::session_flags
 chroot_file::get_session_flags () const
 {
-  return SESSION_CREATE;
+  return SESSION_CREATE | chroot_source::get_session_flags();
 }
 
 void
@@ -178,18 +170,21 @@ chroot_file::get_keyfile (keyfile& keyfile) const
 }
 
 void
-chroot_file::set_keyfile (keyfile const& keyfile)
+chroot_file::set_keyfile (keyfile const& keyfile,
+			  string_list&   used_keys)
 {
-  chroot::set_keyfile(keyfile);
-  chroot_source::set_keyfile(keyfile);
+  chroot::set_keyfile(keyfile, used_keys);
+  chroot_source::set_keyfile(keyfile, used_keys);
 
   keyfile::get_object_value(*this, &chroot_file::set_file,
 			    keyfile, get_name(), "file",
 			    keyfile::PRIORITY_REQUIRED);
+  used_keys.push_back("file");
 
   keyfile::get_object_value(*this, &chroot_file::set_file_repack,
 			    keyfile, get_name(), "file-repack",
 			    get_active() ?
 			    keyfile::PRIORITY_REQUIRED :
 			    keyfile::PRIORITY_DISALLOWED);
+  used_keys.push_back("file-repack");
 }
