@@ -1,8 +1,8 @@
-/* Copyright © 2005-2007  Roger Leigh <rleigh@debian.org>
+/* Copyright © 2005-2008  Roger Leigh <rleigh@debian.org>
  *
- * schroot is free software; you can redistribute it and/or modify it
+ * schroot is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * schroot is distributed in the hope that it will be useful, but
@@ -11,9 +11,8 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
- * MA  02111-1307  USA
+ * along with this program.  If not, see
+ * <http://www.gnu.org/licenses/>.
  *
  *********************************************************************/
 
@@ -104,7 +103,7 @@ namespace sbuild
 
     /**
      * Get the users allowed to access the source chroot as root.
-     * Mmebers of these users can switch to root without
+     * Members of these users can switch to root without
      * authenticating themselves.
      *
      * @returns a list of users.
@@ -114,7 +113,7 @@ namespace sbuild
 
     /**
      * Set the users allowed to access the source chroot as root.
-     * Mmebers of these users can switch to root without
+     * Members of these users can switch to root without
      * authenticating themselves.
      *
      * @param users a list of users.
@@ -124,7 +123,7 @@ namespace sbuild
 
     /**
      * Get the groups allowed to access the source chroot as root.
-     * Mmebers of these groups can switch to root without
+     * Members of these groups can switch to root without
      * authenticating themselves.
      *
      * @returns a list of groups.
@@ -134,7 +133,7 @@ namespace sbuild
 
     /**
      * Set the groups allowed to access the source chroot as root.
-     * Mmebers of these groups can switch to root without
+     * Members of these groups can switch to root without
      * authenticating themselves.
      *
      * @param groups a list of groups.
@@ -146,6 +145,9 @@ namespace sbuild
     setup_env (environment& env);
 
   protected:
+    virtual session_flags
+    get_session_flags () const;
+
     virtual void
     get_details (format_detail& detail) const;
 
@@ -153,9 +155,12 @@ namespace sbuild
     get_keyfile (keyfile& keyfile) const;
 
     void
-    set_keyfile (keyfile const& keyfile);
+    set_keyfile (keyfile const& keyfile,
+		 string_list&   used_keys);
 
   private:
+    /// Is the chroot source or clone?
+    bool          is_source;
     /// Users allowed to access the source chroot.
     string_list   source_users;
     /// Groups allowed to access the source chroot.
