@@ -1,8 +1,8 @@
-/* Copyright © 2005-2007  Roger Leigh <rleigh@debian.org>
+/* Copyright © 2005-2008  Roger Leigh <rleigh@debian.org>
  *
- * schroot is free software; you can redistribute it and/or modify it
+ * schroot is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * schroot is distributed in the hope that it will be useful, but
@@ -11,9 +11,8 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
- * MA  02111-1307  USA
+ * along with this program.  If not, see
+ * <http://www.gnu.org/licenses/>.
  *
  *********************************************************************/
 
@@ -57,7 +56,10 @@ namespace sbuild
     /// Chroot session properties
     enum session_flags
       {
-	SESSION_CREATE = 1 << 0 ///< The chroot supports session creation.
+	SESSION_NOFLAGS = 0,     ///< No flags are set.
+	SESSION_CREATE = 1 << 0, ///< The chroot supports session creation.
+	SESSION_CLONE  = 1 << 1, ///< The chroot supports cloning.
+	SESSION_PURGE  = 1 << 2  ///< The chroot should be purged.
       };
 
     /// Error codes.
@@ -69,14 +71,12 @@ namespace sbuild
 	DEVICE_ABS,      ///< Device must have an absolute path.
 	DEVICE_LOCK,     ///< Failed to lock device.
 	DEVICE_NOTBLOCK, ///< File is not a block device.
-	DEVICE_STAT,     ///< Failed to stat device.
 	DEVICE_UNLOCK,   ///< Failed to unlock device.
 	FILE_ABS,        ///< File must have an absolute path.
 	FILE_LOCK,       ///< Failed to acquire lock.
 	FILE_NOTREG,     ///< File is not a regular file.
 	FILE_OWNER,      ///< File is not owned by user root.
 	FILE_PERMS,      ///< File has write permissions for others.
-	FILE_STAT,       ///< Failed to stat file.
 	FILE_UNLOCK,     ///< Failed to discard lock.
 	LOCATION_ABS,    ///< Location must have an absolute path.
 	SESSION_UNLINK,  ///< Failed to unlink session file.
@@ -265,7 +265,7 @@ namespace sbuild
     set_groups (string_list const& groups);
 
     /**
-     * Get the users allowed to access the chroot as root.  Mmebers
+     * Get the users allowed to access the chroot as root.  Members
      * of these users can switch to root without authenticating
      * themselves.
      *
@@ -275,7 +275,7 @@ namespace sbuild
     get_root_users () const;
 
     /**
-     * Set the users allowed to access the chroot as root.  Mmebers
+     * Set the users allowed to access the chroot as root.  Members
      * of these users can switch to root without authenticating
      * themselves.
      *
@@ -285,7 +285,7 @@ namespace sbuild
     set_root_users (string_list const& users);
 
     /**
-     * Get the groups allowed to access the chroot as root.  Mmebers
+     * Get the groups allowed to access the chroot as root.  Members
      * of these groups can switch to root without authenticating
      * themselves.
      *
@@ -295,7 +295,7 @@ namespace sbuild
     get_root_groups () const;
 
     /**
-     * Set the groups allowed to access the chroot as root.  Mmebers
+     * Set the groups allowed to access the chroot as root.  Members
      * of these groups can switch to root without authenticating
      * themselves.
      *
@@ -573,7 +573,9 @@ namespace sbuild
     operator >> (keyfile const& keyfile,
 		 ptr&           rhs)
     {
-      rhs->set_keyfile(keyfile);
+      string_list used;
+      rhs->set_keyfile(keyfile, used);
+      keyfile.check_keys(rhs->get_name(), used);
       return keyfile;
     }
 
@@ -625,9 +627,11 @@ namespace sbuild
      * be determined.
      *
      * @param keyfile the keyfile to get the properties from.
+     * @param used_keys a list of the keys used will be set.
      */
     virtual void
-    set_keyfile (keyfile const& keyfile);
+    set_keyfile (keyfile const& keyfile,
+		 string_list&   used_keys);
 
   private:
     /// Chroot name.
@@ -670,6 +674,34 @@ namespace sbuild
     personality   persona;
   };
 
+  /**
+   * Bitwise-OR of specifed session properties
+   * @param lhs session properties
+   * @param rhs session properties
+   * @returns result of OR.
+   */
+  chroot::session_flags
+  inline operator | (chroot::session_flags const& lhs,
+		     chroot::session_flags const& rhs)
+  {
+    return static_cast<chroot::session_flags>
+      (static_cast<int>(lhs) | static_cast<int>(rhs));
+  }
+
+  /**
+   * Bitwise-AND of specifed session properties
+   * @param lhs session properties
+   * @param rhs session properties
+   * @returns result of AND.
+   */
+  chroot::session_flags
+  inline operator & (chroot::session_flags const& lhs,
+		     chroot::session_flags const& rhs)
+  {
+    return static_cast<chroot::session_flags>
+      (static_cast<int>(lhs) & static_cast<int>(rhs));
+  }
+
 }
 
 #endif /* SBUILD_CHROOT_H */
