@@ -1,8 +1,8 @@
 /* Copyright © 2005-2007  Roger Leigh <rleigh@debian.org>
  *
- * schroot is free software; you can redistribute it and/or modify it
+ * schroot is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * schroot is distributed in the hope that it will be useful, but
@@ -11,9 +11,8 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
- * MA  02111-1307  USA
+ * along with this program.  If not, see
+ * <http://www.gnu.org/licenses/>.
  *
  *********************************************************************/
 
@@ -741,13 +740,17 @@ session::get_shell () const
   assert (!auth::get_shell().empty());
   std::string shell = auth::get_shell();
 
-  struct stat statbuf;
-  if (stat(shell.c_str(), &statbuf) < 0)
+  try
     {
+      stat(shell).check();
+    }
+  catch (std::runtime_error const& e)
+    {
+      error e1(shell, SHELL, e.what());
+      log_exception_warning(e1);
+
       if (shell != "/bin/sh")
 	{
-	  error e1(shell, SHELL, strerror(errno));
-	  log_exception_warning(e1);
 	  shell = "/bin/sh";
 	  error e2(SHELL_FB, shell);
 	  log_exception_warning(e2);
