@@ -1,8 +1,8 @@
-/* Copyright © 2006-2007  Roger Leigh <rleigh@debian.org>
+/* Copyright © 2006-2008  Roger Leigh <rleigh@debian.org>
  *
- * schroot is free software; you can redistribute it and/or modify it
+ * schroot is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * schroot is distributed in the hope that it will be useful, but
@@ -11,9 +11,8 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
- * MA  02111-1307  USA
+ * along with this program.  If not, see
+ * <http://www.gnu.org/licenses/>.
  *
  *********************************************************************/
 
@@ -91,6 +90,9 @@ public:
     expected.add("CHROOT_PATH",           "/mnt/mount-location");
     expected.add("CHROOT_MOUNT_DEVICE",   "/dev/device-to-mount");
     expected.add("CHROOT_SCRIPT_CONFIG",  sbuild::normalname(std::string(PACKAGE_SYSCONF_DIR) + "/script-defaults"));
+    expected.add("CHROOT_SESSION_CLONE", "true");
+    expected.add("CHROOT_SESSION_CREATE", "true");
+    expected.add("CHROOT_SESSION_PURGE", "false");
 
     test_chroot_base<chroot_file>::test_setup_env(expected);
   }
@@ -98,7 +100,8 @@ public:
   void test_session_flags()
   {
     CPPUNIT_ASSERT(chroot->get_session_flags() ==
-		   sbuild::chroot::SESSION_CREATE);
+		   (sbuild::chroot::SESSION_CREATE |
+		    sbuild::chroot::SESSION_CLONE));
   }
 
   void test_print_details()
